==> developer-center-api-3.4.10-sources.jar: cn/com/duiba/developer/center/api/remoteservice/RemoteAppService.java <==
package cn.com.duiba.developer.center.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.developer.center.api.domain.dto.AppBudgetDto;
import cn.com.duiba.developer.center.api.domain.dto.AppContainDeveloperInfoDto;
import cn.com.duiba.developer.center.api.domain.dto.AppManagerDto;
import cn.com.duiba.developer.center.api.domain.dto.AppSimpleDto;
import cn.com.duiba.developer.center.api.domain.dto.app.AppDeveloperSimpleInfoDto;
import cn.com.duiba.developer.center.api.domain.dto.app.TuiaAppDto;
import cn.com.duiba.developer.center.api.domain.paramquery.AppBudget4Update;
import cn.com.duiba.developer.center.api.domain.paramquery.AppBudgetParam;
import cn.com.duiba.developer.center.api.domain.paramquery.AppDeveloperSimpleQryParams;
import cn.com.duiba.developer.center.api.domain.paramquery.AppExtraParams;
import cn.com.duiba.developer.center.api.domain.paramquery.AppInfoFromParams;
import cn.com.duiba.developer.center.api.domain.paramquery.AppSimpleQueryParams;
import cn.com.duiba.developer.center.api.domain.paramquery.AppSwitchParam;
import cn.com.duiba.developer.center.api.domain.paramquery.AppUrlParams;
import cn.com.duiba.developer.center.api.domain.paramquery.CreateAppQueryParams;
import cn.com.duiba.developer.center.api.domain.vo.AppDeveloperVO;
import cn.com.duiba.developer.center.api.domain.vo.PaginationVO;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.springframework.web.bind.annotation.RequestMapping;

import java.util.List;
import java.util.Map;

/**
 * Created by liuyao on 16/7/29.
 */
@AdvancedFeignClient
public interface RemoteAppService {
    /**
     * 创建App,注册时请不要调此服务,因为注册服务会自动完成app的创建
     *
     * @param param
     * @return
     */
    DubboResult<Long> createApp(CreateAppQueryParams param);

    /**
     * 获取App简单字段(可高并发)
     *
     * @param id
     * @return
     */
    DubboResult<AppSimpleDto> getSimpleApp(Long id);

    /**
     * 批量获取App简单字段
     *
     * @param id
     * @return
     */
    DubboResult<List<AppSimpleDto>> getSimpleAppByIds(List<Long> id);

    /**
     * 获取app预算
     *
     * @param id
     * @return
     */
    DubboResult<AppBudgetDto> getAppBudget(Long id);

    /**
     * 更新应用配置信息
     *
     * @param params
     * @return
     */
    @Deprecated
    @RequestMapping("DeprecatedUpdateAppInfo")
    DubboResult<Boolean> updateAppInfo(AppInfoFromParams params);

    /**
     * app接口配置
     *
     * @param appUrlParams
     * @return
     */
    DubboResult<Boolean> updateApiConfig(AppUrlParams appUrlParams);

    /**
     * app预算配置
     *
     * @param appBudget
     * @return
     */
    DubboResult<Boolean> updateBudgetConfig(AppBudget4Update appBudget);

    /**
     * 更新app配置
     *
     * @param appExtraParams
     */
    void saveAppConfig(AppExtraParams appExtraParams);

    /**
     * 通过appKey查询app
     *
     * @param appKey
     * @return
     */
    DubboResult<AppSimpleDto> getAppByAppKey(String appKey);

    /**
     * 通过开发者ID查询app的信息
     *
     * @param developerId
     * @return
     */
    DubboResult<List<AppSimpleDto>> findAllByDeveloper(Long developerId);

    /**
     * 根据应用名称查询(前模糊)app的信息
     *
     * @param appName 应用名称
     * @return
     */
    DubboResult<List<AppSimpleDto>> findAppNameByNameLike(String appName);

    /**
     * 根据应用名称模糊查询前20条
     *
     * @param appName 应用名称
     * @return
     */
    DubboResult<List<AppSimpleDto>> findAppByAppName(String appName);

    /**
     * 根据定向列表和黑名单列表查询app信息
     *
     * @param specifyAppIds 定向appId列表
     * @param blackDevIds   黑名单开发者Id列表
     * @return
     */
    DubboResult<List<AppSimpleDto>> findAppBySpecifyAndBlack(List<Long> specifyAppIds, List<Long> blackDevIds);

    /**
     * 根据enable appType appname和email进行分页查询
     *
     * @param queryMap
     * @return
     */
    DubboResult<List<AppManagerDto>> findAppListByCondition(Map<String, Object> queryMap);

    /**
     * 根据enable appType appname和email进行查询总数
     *
     * @param queryMap
     * @return
     */
    DubboResult<Integer> findAppListCount(Map<String, Object> queryMap);

    /**
     * 查询app信息
     *
     * @param appIds
     * @return
     */
    DubboResult<List<AppManagerDto>> findByAppIdsManagerDto(List<Long> appIds);

    /**
     * 扣除预算，用于创建订单流程中
     */
    DubboResult<Boolean> deductBudget(AppBudgetParam param);

    /**
     * 返还预算
     */
    DubboResult<Boolean> restoreBudget(AppBudgetParam param);

    /**
     * 更新app开关状态
     * @param appSwtichParam
     * @return
     */
    DubboResult<Boolean> updateAppSwitch(AppSwitchParam appSwtichParam);

    /**
     * 更新app信息，开发者后台与管理端调用
     * @param app
     * @return
     */
    DubboResult<Boolean> updateAppInfo(AppSimpleDto app);


    /**
     * 广告平台调用
     * 获取最大和最小appIid
     * key:maxId,minId
     * @return，
     */
    DubboResult<Map<String,Long>> getMaxMinAppId();

    /**
     * 广告平台调用
     * 分批次获取兑吧App数据
     * @param minId 开始ID
     * @param maxId 结束ID
     * @return
     */
    DubboResult<List<TuiaAppDto>> getDuiBaAppData(Long minId, Long maxId);

    /**
     * @param specifyAppIds 定向的appIds
     * @param blackAppIds 黑名单appIds
     * @return
     */
    DubboResult<List<AppSimpleDto>> findAllBySpecifyAndBlack(List<Long> specifyAppIds, List<Long> blackAppIds);

    /**
     *
     * @param itemIdMap: key: itemId, value: appIdList
     * @return
     */
    DubboResult<Map<Long, Integer>> countItemAutoRecommandApp(Map<Long, List<Long>> itemIdMap);

    /**
     *
     * @param appIds
     * @return
     */
    DubboResult<List<Long>> getAutoRecommandAppIdListByAppId(List<Long> appIds);

    /**
     * 根据开发者id集合获取对应的所有appId
     * @param developerIds
     * @return
     */
    List<Long> findAllAppIdsByDevelopIds(List<Long> developerIds);
    
    /**
     * 批量更新 当月剩余预算
     * @return
     */
    Boolean updatBudgetRemain();
    
    /**
     * 查询 所有app信息
     *
     * @param appIds
     * @return
     */
    List<AppManagerDto> findByAllAppIdsManagerDto(List<Long> appIds);

	/**
     * 分页查询开放兑换通知的app列表
     * @return
     */
    PaginationVO<AppSimpleDto> queryRecordNotifyByPage(AppSimpleQueryParams params);

	/**
     * 更新app兑换记录通知url
     * recordNotifyUrl为空则代表关闭通知
     * @param dto
     * @return
     */
    Boolean updateAppRecordNotifyUrl(AppSimpleDto dto);

	/**
     * 查询开放了兑换通知的appId列表
     * @return
     */
    List<Long> queryRecordNofityAppIdList();

    /**
     * 根据开发者id集合获取对应的所有AppSimpleDto
     * @param developerIds
     * @return
     */
    public List<AppSimpleDto> findAllByDeveloperIds(List<Long> developerIds);

    /**
     * 查询开发者 邮箱和 应用名称等信息
     * @param appId
     * @return
     */
    public Map<String, Object> selectOneAppDeveloper(Long appId);

    /**
     * 根据appId 查询APP信息（包含部分开发者信息）
     * @param appId
     * @return
     */
    AppContainDeveloperInfoDto selectOneAppContainDeveloperInfo(Long appId);

    /**
     * 根据邮箱名称 查询appId
     * @param email
     * @return
     */
    public List<Long> selectAppIdByEmail(String email);

    /**
     * 根据app名称 查询appId
     * @param appName
     * @return
     */
    List<Long> selectAppIdByName(String appName);

    /**
     * 查询app总数
     * @return
     */
    Integer countApp();

    /**
     * 根据邮箱和appName 查询appId
     * @return
     */
    List<Long> selectAppIdByEmailAndName(String email, String appName);

    /**
     * 查询所有app
     * @param start
     * @param pageSize
     * @return
     */
    List<AppDeveloperVO> selectAllAppDeveloper(Integer start, Integer pageSize);

    /**
     * AppDeveloperVO
     * @param appIdList
     * @return
     */
    List<AppDeveloperVO> selectAppDeveloperByAppId(List<Long> appIdList);

    /**
     * 找到第一个创建的App
     * @param developerId
     * @return
     */
    AppSimpleDto findFristAppByDeveloperId(Long developerId);


    List<Long> findAppIdListByMinId(Long minId);

    /**
     * 批量获取App
     * @param ids
     * @return
     */
    List<AppSimpleDto> findByIds(List<Long> ids);

    /**
     * 更改app关联的developerId
     * @param id
     * @param developerId
     * @return
     */
    Integer updateDeveloperId(Long id,Long developerId);

    /**
     * 分页查询列表
     * @param qryParams
     * @return
     */
    List<AppDeveloperSimpleInfoDto> findAllAppDeveloper4page(AppDeveloperSimpleQryParams qryParams);

    Integer count4AllAppDeveloperPage(AppDeveloperSimpleQryParams qryParams);

    Boolean belongToAmbApp(Long appId) throws BizException;
}

==> developer-center-api-3.5.22-sources.jar: cn/com/duiba/developer/center/api/remoteservice/RemoteAppService.java <==
package cn.com.duiba.developer.center.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.developer.center.api.domain.dto.AppBudgetDto;
import cn.com.duiba.developer.center.api.domain.dto.AppContainDeveloperInfoDto;
import cn.com.duiba.developer.center.api.domain.dto.AppManagerDto;
import cn.com.duiba.developer.center.api.domain.dto.AppSimpleDto;
import cn.com.duiba.developer.center.api.domain.dto.app.AppDeveloperSimpleInfoDto;
import cn.com.duiba.developer.center.api.domain.dto.app.TuiaAppDto;
import cn.com.duiba.developer.center.api.domain.paramquery.AppBudget4Update;
import cn.com.duiba.developer.center.api.domain.paramquery.AppBudgetParam;
import cn.com.duiba.developer.center.api.domain.paramquery.AppDeveloperSimpleQryParams;
import cn.com.duiba.developer.center.api.domain.paramquery.AppExtraParams;
import cn.com.duiba.developer.center.api.domain.paramquery.AppInfoFromParams;
import cn.com.duiba.developer.center.api.domain.paramquery.AppSimpleQueryParams;
import cn.com.duiba.developer.center.api.domain.paramquery.AppSwitchParam;
import cn.com.duiba.developer.center.api.domain.paramquery.AppUrlParams;
import cn.com.duiba.developer.center.api.domain.paramquery.CreateAppQueryParams;
import cn.com.duiba.developer.center.api.domain.vo.AppDeveloperVO;
import cn.com.duiba.developer.center.api.domain.vo.PaginationVO;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.springframework.web.bind.annotation.RequestMapping;

import java.util.List;
import java.util.Map;

/**
 * Created by liuyao on 16/7/29.
 */
@AdvancedFeignClient
public interface RemoteAppService {
    /**
     * 创建App,注册时请不要调此服务,因为注册服务会自动完成app的创建
     *
     * @param param
     * @return
     */
    DubboResult<Long> createApp(CreateAppQueryParams param);

    /**
     * 获取App简单字段(可高并发)
     *
     * @param id
     * @return
     */
    DubboResult<AppSimpleDto> getSimpleApp(Long id);

    /**
     * 获取app简单字段（无缓存，适合管理端使用）
     * @param id
     * @return
     */
    AppSimpleDto getSimpleAppNoCache(Long id);

    /**
     * 批量获取App简单字段
     *
     * @param id
     * @return
     */
    DubboResult<List<AppSimpleDto>> getSimpleAppByIds(List<Long> id);

    /**
     * 获取app预算
     *
     * @param id
     * @return
     */
    DubboResult<AppBudgetDto> getAppBudget(Long id);

    /**
     * 更新应用配置信息
     *
     * @param params
     * @return
     */
    @Deprecated
    @RequestMapping("DeprecatedUpdateAppInfo")
    DubboResult<Boolean> updateAppInfo(AppInfoFromParams params);

    /**
     * app接口配置
     *
     * @param appUrlParams
     * @return
     */
    DubboResult<Boolean> updateApiConfig(AppUrlParams appUrlParams);

    /**
     * app预算配置
     *
     * @param appBudget
     * @return
     */
    DubboResult<Boolean> updateBudgetConfig(AppBudget4Update appBudget);

    /**
     * 更新app配置
     *
     * @param appExtraParams
     */
    void saveAppConfig(AppExtraParams appExtraParams);

    /**
     * 通过appKey查询app
     *
     * @param appKey
     * @return
     */
    DubboResult<AppSimpleDto> getAppByAppKey(String appKey);

    /**
     * 通过开发者ID查询app的信息
     *
     * @param developerId
     * @return
     */
    DubboResult<List<AppSimpleDto>> findAllByDeveloper(Long developerId);

    /**
     * 根据应用名称查询(前模糊)app的信息
     *
     * @param appName 应用名称
     * @return
     */
    DubboResult<List<AppSimpleDto>> findAppNameByNameLike(String appName);

    /**
     * 根据应用名称模糊查询前20条
     *
     * @param appName 应用名称
     * @return
     */
    DubboResult<List<AppSimpleDto>> findAppByAppName(String appName);

    /**
     * 根据定向列表和黑名单列表查询app信息
     *
     * @param specifyAppIds 定向appId列表
     * @param blackDevIds   黑名单开发者Id列表
     * @return
     */
    DubboResult<List<AppSimpleDto>> findAppBySpecifyAndBlack(List<Long> specifyAppIds, List<Long> blackDevIds);

    /**
     * 根据enable appType appname和email进行分页查询
     *
     * @param queryMap
     * @return
     */
    DubboResult<List<AppManagerDto>> findAppListByCondition(Map<String, Object> queryMap);

    /**
     * 根据enable appType appname和email进行查询总数
     *
     * @param queryMap
     * @return
     */
    DubboResult<Integer> findAppListCount(Map<String, Object> queryMap);

    /**
     * 查询app信息
     *
     * @param appIds
     * @return
     */
    DubboResult<List<AppManagerDto>> findByAppIdsManagerDto(List<Long> appIds);

    /**
     * 扣除预算，用于创建订单流程中
     */
    DubboResult<Boolean> deductBudget(AppBudgetParam param);

    /**
     * 返还预算
     */
    DubboResult<Boolean> restoreBudget(AppBudgetParam param);

    /**
     * 更新app开关状态
     * @param appSwtichParam
     * @return
     */
    DubboResult<Boolean> updateAppSwitch(AppSwitchParam appSwtichParam);

    /**
     * 更新app信息，开发者后台与管理端调用
     * @param app
     * @return
     */
    DubboResult<Boolean> updateAppInfo(AppSimpleDto app);


    /**
     * 广告平台调用
     * 获取最大和最小appIid
     * key:maxId,minId
     * @return，
     */
    DubboResult<Map<String,Long>> getMaxMinAppId();

    /**
     * 广告平台调用
     * 分批次获取兑吧App数据
     * @param minId 开始ID
     * @param maxId 结束ID
     * @return
     */
    DubboResult<List<TuiaAppDto>> getDuiBaAppData(Long minId, Long maxId);

    /**
     * @param specifyAppIds 定向的appIds
     * @param blackAppIds 黑名单appIds
     * @return
     */
    DubboResult<List<AppSimpleDto>> findAllBySpecifyAndBlack(List<Long> specifyAppIds, List<Long> blackAppIds);

    /**
     *
     * @param itemIdMap: key: itemId, value: appIdList
     * @return
     */
    DubboResult<Map<Long, Integer>> countItemAutoRecommandApp(Map<Long, List<Long>> itemIdMap);

    /**
     *
     * @param appIds
     * @return
     */
    DubboResult<List<Long>> getAutoRecommandAppIdListByAppId(List<Long> appIds);

    /**
     * 根据开发者id集合获取对应的所有appId
     * @param developerIds
     * @return
     */
    List<Long> findAllAppIdsByDevelopIds(List<Long> developerIds);
    
    /**
     * 批量更新 当月剩余预算
     * @return
     */
    Boolean updatBudgetRemain();
    
    /**
     * 查询 所有app信息
     *
     * @param appIds
     * @return
     */
    List<AppManagerDto> findByAllAppIdsManagerDto(List<Long> appIds);

	/**
     * 分页查询开放兑换通知的app列表
     * @return
     */
    PaginationVO<AppSimpleDto> queryRecordNotifyByPage(AppSimpleQueryParams params);

	/**
     * 更新app兑换记录通知url
     * recordNotifyUrl为空则代表关闭通知
     * @param dto
     * @return
     */
    Boolean updateAppRecordNotifyUrl(AppSimpleDto dto);

	/**
     * 查询开放了兑换通知的appId列表
     * @return
     */
    List<Long> queryRecordNofityAppIdList();

    /**
     * 根据开发者id集合获取对应的所有AppSimpleDto
     * @param developerIds
     * @return
     */
    public List<AppSimpleDto> findAllByDeveloperIds(List<Long> developerIds);

    /**
     * 查询开发者 邮箱和 应用名称等信息
     * @param appId
     * @return
     */
    public Map<String, Object> selectOneAppDeveloper(Long appId);

    /**
     * 根据appId 查询APP信息（包含部分开发者信息）
     * @param appId
     * @return
     */
    AppContainDeveloperInfoDto selectOneAppContainDeveloperInfo(Long appId);

    /**
     * 根据邮箱名称 查询appId
     * @param email
     * @return
     */
    public List<Long> selectAppIdByEmail(String email);

    /**
     * 根据app名称 查询appId
     * @param appName
     * @return
     */
    List<Long> selectAppIdByName(String appName);

    /**
     * 查询app总数
     * @return
     */
    Integer countApp();

    /**
     * 根据邮箱和appName 查询appId
     * @return
     */
    List<Long> selectAppIdByEmailAndName(String email, String appName);

    /**
     * 查询所有app
     * @param start
     * @param pageSize
     * @return
     */
    List<AppDeveloperVO> selectAllAppDeveloper(Integer start, Integer pageSize);

    /**
     * AppDeveloperVO
     * @param appIdList
     * @return
     */
    List<AppDeveloperVO> selectAppDeveloperByAppId(List<Long> appIdList);

    /**
     * 找到第一个创建的App
     * @param developerId
     * @return
     */
    AppSimpleDto findFristAppByDeveloperId(Long developerId);


    List<Long> findAppIdListByMinId(Long minId);

    /**
     * 批量获取App
     * @param ids
     * @return
     */
    List<AppSimpleDto> findByIds(List<Long> ids);

    /**
     * 更改app关联的developerId
     * @param id
     * @param developerId
     * @return
     */
    Integer updateDeveloperId(Long id,Long developerId);

    /**
     * 分页查询列表
     * @param qryParams
     * @return
     */
    List<AppDeveloperSimpleInfoDto> findAllAppDeveloper4page(AppDeveloperSimpleQryParams qryParams);

    Integer count4AllAppDeveloperPage(AppDeveloperSimpleQryParams qryParams);

    Boolean belongToAmbApp(Long appId) throws BizException;

    /**
     * 判断是不是苏宁易购app
     * @param appId
     * @return
     */
    Boolean belongToSuningHdtoolApp(Long appId);

    /**
     * 判断是不是苏州农商行app
     * @param appId
     * @return
     */
    Boolean belongToWjrcbApp(Long appId);

    /**
     * 查询开启的支付渠道
     * @param appId
     * @return
     */
    List<String> selectOpenAppPayChannelTypeByAppId(Long appId);

    /**
     * 设置支付渠道
     * @param appId
     * @param appPayChannelTypeList
     * @return
     */
    Boolean updateAppPayChannel(Long appId,List<String> appPayChannelTypeList);

    /**
     * 获取苏宁share url
     * @return
     */
    String getSuningShareUrl();

    /**
     * 更新全局色配置
     * @param appId
     * @param colorSwitch
     * @param color
     * @return
     */
    boolean updateAppColorNew(Long appId, boolean colorSwitch, String color);
}
